@@ -1,5 +1,5 @@
 package Git::Repository::Command;
-$Git::Repository::Command::VERSION = '1.315';
+$Git::Repository::Command::VERSION = '1.316';
 use strict;
 use warnings;
 use 5.006;
@@ -164,8 +164,8 @@ sub final_output {
     my ( @output, @errput );
     {
         local $/ = "\n";
-        chomp( @output = <$stdout> );
-        chomp( @errput = <$stderr> );
+        chomp( @output = <$stdout> ) if $stdout->opened;
+        chomp( @errput = <$stderr> ) if $stderr->opened;
     }
 
     # done with it
